.. role:: python(code)
   :language: python

####################################################
django-settings-local - Manage Django Local Settings
####################################################

.. image:: https://img.shields.io/pypi/v/django-settings-local.svg
        :target: https://pypi.org/project/django-settings-local

.. image:: https://img.shields.io/pypi/pyversions/django-settings-local.svg
        :target: https://pypi.org/project/django-settings-local

.. image:: https://github.com/fasih/django-settings-local/workflows/build/badge.svg
        :target: https://github.com/fasih/django-settings-local/actions?query=workflow:build

.. image:: https://github.com/fasih/django-settings-local/workflows/publish/badge.svg
        :target: https://github.com/fasih/django-settings-local/actions?query=workflow:publish

.. image:: https://codecov.io/gh/fasih/django-settings-local/branch/develop/graph/badge.svg?token=YDO44RQBSS
      :target: https://codecov.io/gh/fasih/django-settings-local
    
*****
Usage
*****

0. Installation
===============

The preferred instalation method is directly from pypi:

.. code:: console

   pip install -U django-settings-local


1. Quickstart
=============

In your Django project app directory:

.. code:: console

   dsl
   
2. Quickhelp
=============

Quick help from simple console script:

.. code:: console

   dsl -h
